@@ -29,6 +29,7 @@ class networksettings:
 	
 	is_wireless = False
 	use_any_essid = True
+	power_management = True
 	use_dhcp = True
 	get_dns_auto = True
 	w_mode = "managed"
@@ -298,6 +299,12 @@ case "$ADDRESS" in
 		vbox.pack_start(self.use_any_essid_check, gtk.FALSE, gtk.FALSE)
 		self.use_any_essid_check.set_border_width(4)
 
+	# Use Power management checkbox
+		self.power_management_check = gtk.CheckButton("Power management")
+		self.power_management_check.connect("toggled", self.toggle_power_management)
+		vbox.pack_start(self.power_management_check, gtk.FALSE, gtk.FALSE)
+		self.power_management_check.set_border_width(4)
+
 		content_frame = gtk.Frame("Config")
 		content_frame.set_border_width(4)
 		vbox.pack_start(content_frame, gtk.FALSE, gtk.FALSE)
@@ -482,6 +489,13 @@ case "$ADDRESS" in
 			self.use_any_essid = True
 		return
 
+	def toggle_power_management(self,widget):
+		if (self.power_management):
+			self.power_management = False
+		else:
+			self.power_management = True
+		return
+
 	def change_wepkey_type(self,combobox):
 		model = combobox.get_model()
 		active = combobox.get_active()
@@ -516,6 +530,7 @@ case "$ADDRESS" in
 		self.def_domain.set_text("")
 		self.is_wireless = False
 		self.use_any_essid = True
+		self.power_management = True
 		self.use_dhcp = True
 		self.get_dns_auto = True
 		self.w_mode = "managed"
@@ -747,6 +762,15 @@ case "$ADDRESS" in
 										self.authtype_select.set_active(i)
 									i = i + 1
 								self.wepkey.set_text(Networkset.getAttribute("WEPKEY"))
+							if (Networkset.getAttribute("POWER") == "on"):
+								self.power_management = False
+								self.power_management_check.set_active(gtk.TRUE)
+								self.power_management = True
+							else:
+								self.power_management = True
+								self.power_management_check.set_active(gtk.FALSE)
+								self.power_management = False
+								
 						else:
 							self.PROFILELIST.append(Networkset.getAttribute("SETTINGNAME"))
 				return True
@@ -888,6 +912,11 @@ case "$ADDRESS" in
 				net_node.setAttribute("WEPKEY", self.wepkey.get_text())
 			net_node.setAttribute("WEP_AUTHTYPE", self.w_auth)
 		
+		if (self.power_management):
+			net_node.setAttribute("POWER", "on")
+		else:
+			net_node.setAttribute("POWER", "")
+					
 		return
 
 	def make_output_files(self):
@@ -991,7 +1020,10 @@ case "$ADDRESS" in
 											returnstr_wireless += "\tKEY=\"" + Networkset.getAttribute("WEPKEY") + " "+ Networkset.getAttribute("WEP_AUTHTYPE") +"\"\n"
 									else:
 										returnstr_wireless += "\tKEY=\"\"\n"
-
+								
+								if (Networkset.getAttribute("POWER") == "on"):
+									returnstr_wireless += "\tPOWER=\"on\"\n"
+							
 							returnstr_wireless += "\t;;"
 							returnstr_wireless = returnstr_wireless.strip() + "\n\n"
 							
@@ -1048,4 +1080,4 @@ case "$ADDRESS" in
 
 if __name__ == "__main__":
 	networksettings = networksettings()
-	networksettings.main()
\ No newline at end of file
+	networksettings.main()
